@@ -17,7 +17,7 @@ from descriptors import classproperty
 from plumbum import colors
 
 
-__version__ = '0.7.0'
+__version__ = '0.9.0'
 
 __all__ = (
     'cmd',
@@ -441,6 +441,27 @@ class CacheDict(collections.defaultdict):
         return value
 
 
+class _SHH(plumbum.commands.ExecutionModifier):
+    """plumbum execution modifier to ensure output is not echoed to terminal
+
+    essentially a no-op, this may be used to override argcmdr settings
+    and cli flags controlling this feature, on a line-by-line basis, to
+    hide unnecessary or problematic (e.g. highly verbose) command output.
+
+    """
+    __slots__ = ('retcode', 'timeout')
+
+    def __init__(self, retcode=0, timeout=None):
+        self.retcode = retcode
+        self.timeout = timeout
+
+    def __rand__(self, cmd):
+        return cmd.run(retcode=self.retcode, timeout=self.timeout)
+
+
+SHH = _SHH()
+
+
 class Local(Command):
 
     local = CacheDict(plumbum.local.__getitem__)
@@ -454,8 +475,11 @@ class Local(Command):
     local.FG = plumbum.FG
     local.TEE = plumbum.TEE
 
+    # ...(as well as our own)
+    local.SHH = SHH
+
     run_kws = frozenset(('retcode',))
-    run_modifiers = frozenset((plumbum.BG, plumbum.FG, plumbum.TEE))
+    run_modifiers = frozenset((plumbum.BG, plumbum.FG, plumbum.TEE, SHH))
 
     @classmethod
     def base_parser(cls):
@@ -679,6 +703,7 @@ class CommandDecorator:
                  binding=unset,
                  local=False,
                  root=False,
+                 method_name=None,
                  **parser_kwargs):
         if (local or root) and base is not unset:
             raise TypeError("cannot apply 'local' or 'root' functionality to "
@@ -707,6 +732,11 @@ class CommandDecorator:
         else:
             raise TypeError('binding must be either bool, Binding or unset')
 
+        if method_name is None:
+            self.method_name = 'prepare' if issubclass(self.base, Local) else '__call__'
+        else:
+            self.method_name = method_name
+
         self.args = (parser_args, parser_kwargs)
 
     def __call__(self, target):
@@ -718,9 +748,6 @@ class CommandDecorator:
                 return target
 
         elif callable(target):
-            call_name = 'prepare' if issubclass(self.base, Local) else '__call__'
-            call_target = self.binding(target)
-
             return type(
                 target.__name__,
                 (GeneratedCommand, self.base),
@@ -728,7 +755,7 @@ class CommandDecorator:
                     '_args_': args,
                     '__doc__': target.__doc__,
                     '__module__': target.__module__,
-                    call_name: call_target,
+                    self.method_name: self.binding(target),
                 }
             )
 
